%define anolis_release 1

%bcond_with doc

%bcond_without enable_dummy

# fwupd.efi is only available on x86_64 and aarch64
%ifarch x86_64 aarch64
%bcond_without have_uefi
%endif

# flashrom is only available on x86_64 and aarch64
%ifarch x86_64 aarch64
%bcond_without have_flashrom
%endif

# msr is only available on x86_64
%ifarch x86_64
%bcond_without have_msr
%endif

# libsmbios is only available on x86_64
%ifarch x86_64
%bcond_without have_dell
%endif

# thunderbolt is only available on x86_64
%ifarch x86_64
%bcond_without have_thunderbolt
%endif

%bcond_without have_modem_manager

Summary:   Firmware update daemon
Name:      fwupd
Version:   1.9.1
Release:   %{anolis_release}%{?dist}
License:   LGPLv2+
URL:       https://github.com/fwupd/fwupd
Source0:   https://github.com/fwupd/fwupd/releases/download/%{version}/%{name}-%{version}.tar.xz

BuildRequires: bash-completion
BuildRequires: gcab
BuildRequires: gettext
BuildRequires: git-core
BuildRequires: gnutls-utils
BuildRequires: meson
BuildRequires: pkgconfig(gi-docgen) >= 2021.1
BuildRequires: pkgconfig(libcbor) >= 0.7.0
BuildRequires: systemd >= 231
BuildRequires: vala

BuildRequires: glib2-devel >= 2.45.8
BuildRequires: gnutls-devel
BuildRequires: gobject-introspection-devel
BuildRequires: json-glib-devel >= 1.1.1
BuildRequires: libarchive-devel
BuildRequires: libxmlb-devel >= 0.1.3
BuildRequires: libgcab1-devel
BuildRequires: libgudev1-devel
BuildRequires: libgusb-devel >= 0.3.5
BuildRequires: libcurl-devel >= 7.62.0
BuildRequires: libjcat-devel >= 0.1.0
BuildRequires: polkit-devel >= 0.103
BuildRequires: protobuf-c-devel
BuildRequires: sqlite-devel
BuildRequires: systemd-devel

%ifarch %{valgrind_arches}
BuildRequires: valgrind
BuildRequires: valgrind-devel
%endif

%if %{with have_flashrom}
BuildRequires: flashrom-devel >= 1.2-2
%endif

%if %{with doc}
BuildRequires:  pandoc
%endif

%if %{with have_modem_manager}
BuildRequires: ModemManager-glib-devel >= 1.10.0
BuildRequires: libqmi-devel >= 1.22.0
BuildRequires: libmbim-devel
%endif

%if %{with have_uefi}
BuildRequires: python3 python3-cairo python3-gobject
BuildRequires: efivar-devel >= 33
BuildRequires: pango-devel
BuildRequires: cairo-devel
BuildRequires: cairo-gobject-devel
BuildRequires: freetype
BuildRequires: fontconfig
BuildRequires: google-noto-sans-cjk-ttc-fonts
BuildRequires: tpm2-tss-devel >= 2.2.3
%endif

%if %{with have_dell}
BuildRequires: efivar-devel >= 33
BuildRequires: libsmbios-devel >= 2.3.0
%endif

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Requires: bubblewrap
Requires: glib2 >= 2.45.8
Requires: libxmlb >= 0.1.3
Requires: libgusb >= 0.3.5
Requires: shared-mime-info

Obsoletes: fwupd-sign < 0.1.6
Obsoletes: fwupd-labels < 1.1.0-1
Obsoletes: libdfu < 1.0.0
Obsoletes: libebitdo < 0.7.5-3


Obsoletes: dbxtool < 9
Provides: dbxtool

Recommends: bluez
Recommends: jq
Recommends: udisks2

%if %{with have_flashrom}
Recommends: %{name}-plugin-flashrom
%endif
%if %{with have_modem_manager}
Recommends: %{name}-plugin-modem-manager
%endif
%if %{with have_uefi}
Recommends: %{name}-efi
Recommends: %{name}-plugin-uefi-capsule-data
%endif

%description
fwupd is a daemon aims to make updating firmware on Linux
automatic, safe, and reliable.

It is an open-source project that provides a simple and
easy-to-use interface for updating firmware on Linux systems.
fwupd is designed to work with UEFI firmware and is compatible
with various hardware platforms. It helps users to keep their
system up-to-date by providing automated firmware updates.
fwupd has support for a wide range of hardware devices such
as motherboards, graphics cards, network cards, and more.
It is a reliable and secure firmware update tool that ensures
the firmware updates are safe and error-free. fwupd is widely
used in enterprise environments and is also popular among
Linux enthusiasts.

%package devel
Summary: Development package for %{name}
Requires: %{name} = %{version}-%{release}
Obsoletes: libebitdo-devel < 0.7.5-3
Obsoletes: libdfu-devel < 1.0.0

%description devel
This package contains the development files for %{name}.

%package tests
Summary: Data files for installed tests
Requires: %{name} = %{version}-%{release}

%description tests
This package contains the data files for installed tests.

%if %{with have_flashrom}
%package plugin-flashrom
Summary: %{name} plugin using flashrom
Requires: %{name} = %{version}-%{release}

%description plugin-flashrom
This provides the optional package which is only required on hardware that
can be flashed using flashrom. It is probably not required on servers.
%endif

%if %{with have_modem_manager}
%package plugin-modem-manager
Summary: %{name} plugin using ModemManger
Requires: %{name} = %{version}-%{release}

%description plugin-modem-manager
This provides the optional package which is only required on hardware that
might have mobile broadband hardware. It is probably not required on servers.

%endif



%if %{with have_uefi}
%package plugin-uefi-capsule-data
Summary: Localized data for the UEFI UX capsule
Requires: %{name} = %{version}-%{release}

%description plugin-uefi-capsule-data
This provides the pregenerated BMP artwork for the UX capsule, which allows the
"Installing firmware update..." localized text to be shown during a UEFI firmware
update operation. This subpackage is probably not required on embedded hardware
or server machines.
%endif

%package doc
Summary: Documentation for %{name}
Buildarch: noarch
Requires: %{name} = %{version}-%{release}

%description doc
This package contains the documentation for %{name}.

%prep
%autosetup -p1

%build

%meson \
    -Dcompat_cli=true \
    -Ddocs=enabled \
    -Dtests=true \
%if %{with enable_dummy}
    -Dplugin_dummy=true \
%else
    -Dplugin_dummy=false \
%endif
%if %{with have_flashrom}
    -Dplugin_flashrom=enabled \
%else
    -Dplugin_flashrom=disabled \
%endif
%if %{with have_msr}
    -Dplugin_msr=enabled \
%else
    -Dplugin_msr=disabled \
%endif
%if %{with have_uefi}
    -Defi_binary=false \
    -Dplugin_tpm=enabled \
    -Dplugin_uefi_capsule=enabled \
    -Dplugin_uefi_pk=enabled \
%else
    -Dplugin_tpm=disabled \
    -Dplugin_uefi_capsule=disabled \
    -Dplugin_uefi_pk=disabled \
%endif
%if %{with have_dell}
    -Dplugin_dell=enabled \
    -Dplugin_synaptics_mst=enabled \
%else
    -Dplugin_dell=disabled \
    -Dplugin_synaptics_mst=disabled \
%endif
%if %{with have_modem_manager}
    -Dplugin_modem_manager=enabled \
%else
    -Dplugin_modem_manager=disabled \
%endif
%if %{with doc}
    -Dman=true \
%else
    -Dman=false \
%endif
    -Dbluez=enabled \
    -Dplugin_powerd=disabled \
    -Dsupported_build=enabled

%meson_build

%check
%meson_test

%install
%meson_install

mkdir -p --mode=0700 $RPM_BUILD_ROOT%{_localstatedir}/lib/fwupd/gnupg

mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/cache/fwupd

rm -rf $RPM_BUILD_ROOT/%{_datadir}/installed-tests/fwupd/efi/efivars/*
rm -rf $RPM_BUILD_ROOT/%{_datadir}/installed-tests/fwupd/efi/esrt/entries/entry0/*

%find_lang %{name}

%post
%systemd_post fwupd.service

# change the default keyring type to pkcs in conf files
for conf in %{_sysconfdir}/fwupd/remotes.d/*.conf; do
    if grep -q "Keyring=gpg" "$conf"; then
        sed -i 's/Keyring=gpg/#Keyring=pkcs/g' "$conf";
    fi
done

%preun
%systemd_preun fwupd.service

%postun
%systemd_postun_with_restart fwupd.service

%files -f %{name}.lang
%license COPYING
%dir %{_libexecdir}/fwupd
%{_libexecdir}/fwupd/fwupd
%ifarch i686 x86_64
%{_libexecdir}/fwupd/fwupd-detect-cet
%endif
%{_libexecdir}/fwupd/fwupdoffline
%if %{with have_uefi}
%{_bindir}/fwupdate
%endif
%{_bindir}/dfu-tool
%if %{with have_uefi}
%{_bindir}/dbxtool
%endif
%{_bindir}/fwupdmgr
%{_bindir}/fwupdtool
%{_bindir}/fwupdagent
%dir %{_sysconfdir}/fwupd
%config(noreplace) %{_sysconfdir}/fwupd/fwupd.conf
%dir %{_sysconfdir}/fwupd/bios-settings.d
%{_sysconfdir}/fwupd/bios-settings.d/README.md
%dir %{_sysconfdir}/fwupd/remotes.d
%if %{with have_dell}
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/dell-esrt.conf
%endif
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/lvfs.conf
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/lvfs-testing.conf
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/vendor.conf
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/vendor-directory.conf
%config(noreplace)%{_sysconfdir}/pki/fwupd
%{_sysconfdir}/pki/fwupd-metadata
%if %{with have_msr}
/usr/lib/modules-load.d/fwupd-msr.conf
%endif
%{_datadir}/dbus-1/system.d/org.freedesktop.fwupd.conf
%{_datadir}/bash-completion/completions/fwupdmgr
%{_datadir}/bash-completion/completions/fwupdtool
%{_datadir}/fish/vendor_completions.d/fwupdmgr.fish
%{_datadir}/fwupd/metainfo/org.freedesktop.fwupd*.metainfo.xml
%if %{with have_dell}
%{_datadir}/fwupd/remotes.d/dell-esrt/metadata.xml
%endif
%{_datadir}/fwupd/remotes.d/vendor/firmware/README.md
%{_datadir}/dbus-1/interfaces/org.freedesktop.fwupd.xml
%{_datadir}/polkit-1/actions/org.freedesktop.fwupd.policy
%{_datadir}/polkit-1/rules.d/org.freedesktop.fwupd.rules
%{_datadir}/dbus-1/system-services/org.freedesktop.fwupd.service
%if %{with doc}
%{_mandir}/man1/fwupdtool.1*
%{_mandir}/man1/fwupdagent.1*
%{_mandir}/man1/dfu-tool.1*
%if %{with have_uefi}
%{_mandir}/man1/dbxtool.*
%endif
%{_mandir}/man1/fwupdmgr.1*
%if %{with have_uefi}
%{_mandir}/man1/fwupdate.1*
%endif
%endif
%{_datadir}/metainfo/org.freedesktop.fwupd.metainfo.xml
%{_datadir}/icons/hicolor/scalable/apps/org.freedesktop.fwupd.svg
%{_datadir}/fwupd/firmware_packager.py
%{_datadir}/fwupd/simple_client.py
%{_datadir}/fwupd/add_capsule_header.py
%{_datadir}/fwupd/install_dell_bios_exe.py
%{_unitdir}/fwupd-offline-update.service
%{_unitdir}/fwupd.service
%{_unitdir}/fwupd-refresh.service
%{_unitdir}/fwupd-refresh.timer
%{_presetdir}/fwupd-refresh.preset
%{_unitdir}/system-update.target.wants/
%dir %{_localstatedir}/lib/fwupd
%dir %{_localstatedir}/cache/fwupd
%dir %{_datadir}/fwupd/quirks.d
%{_datadir}/fwupd/quirks.d/builtin.quirk.gz
%if %{with have_uefi}
%{_sysconfdir}/grub.d/35_fwupd
%endif
%{_libdir}/libfwupd.so.2*
%{_libdir}/girepository-1.0/Fwupd-2.0.typelib
/usr/lib/udev/rules.d/*.rules
/usr/lib/systemd/system-shutdown/fwupd.shutdown
%dir %{_libdir}/fwupd-%{version}
%{_libdir}/fwupd-%{version}/libfwupd*.so
%ghost %{_localstatedir}/lib/fwupd/gnupg

%if %{with have_flashrom}
%files plugin-flashrom
%{_libdir}/fwupd-%{version}/libfu_plugin_flashrom.so
%endif
%if %{with have_modem_manager}
%files plugin-modem-manager
%{_libdir}/fwupd-%{version}/libfu_plugin_modem_manager.so
%endif
%if %{with have_uefi}
%files plugin-uefi-capsule-data
%{_datadir}/fwupd/uefi-capsule-ux.tar.xz
%endif

%files devel
%{_datadir}/gir-1.0/Fwupd-2.0.gir
%{_datadir}/doc/fwupd/libfwupdplugin
%{_datadir}/doc/fwupd/libfwupd
%{_datadir}/doc/libfwupdplugin
%{_datadir}/doc/libfwupd
%{_datadir}/vala/vapi
%{_includedir}/fwupd-1
%{_libdir}/libfwupd*.so
%{_libdir}/pkgconfig/fwupd.pc

%files tests
%{_datadir}/fwupd/host-emulate.d/*.json.gz
%dir %{_datadir}/installed-tests/fwupd
%{_datadir}/installed-tests/fwupd/tests/*
%{_datadir}/installed-tests/fwupd/fwupd-tests.xml
%{_datadir}/installed-tests/fwupd/*.test
%{_datadir}/installed-tests/fwupd/*.cab
%{_datadir}/installed-tests/fwupd/*.sh
%{_datadir}/installed-tests/fwupd/*.zip
%if %{with have_uefi}
%{_datadir}/installed-tests/fwupd/efi
%endif
%{_datadir}/installed-tests/fwupd/chassis_type
%{_datadir}/installed-tests/fwupd/sys_vendor
%{_libexecdir}/installed-tests/fwupd/*
%dir %{_sysconfdir}/fwupd/remotes.d
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/fwupd-tests.conf

%files doc
%doc README.md COMMITMENT RELEASE SECURITY.md
%{_datadir}/doc/fwupd/*.html

%changelog
* Sun May 14 2023 Funda Wang <fundawang@yeah.net> - 1.9.1-1
- New version 1.9.1

* Tue Apr 11 2023 Kun(llfl) <llfl@linux.alibaba.com> - 1.8.12-4
- optimize spec file
- change the keyring operation to install part

* Tue Mar 28 2023 happy_orange <songnannan@linux.alibaba.com> - 1.8.12-3
- disabled doc because of the pandoc

* Tue Mar 7 2023 Funda Wang <fundawang@yeah.net> - 1.8.12-2
- Rebuild for new libcbor

* Sun Feb 26 2023 Funda Wang <fundawang@yeah.net> - 1.8.12-1
- New version 1.8.12

* Thu Dec 29 2022 Funda Wang <fundawang@yeah.net> - 1.8.8-1
- New verison 1.8.8

* Tue Mar 08 2022 Jacob Wang <yungao.jacob@linux.alibaba.com> - 1.7.5-1
- Initial version from upstream 1.7.5
